@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .BaseScreen import *
-from .ScriptContext import *
-from .RunningContextContainer import *
+from .BaseScreen import BaseScreen
+from .BaseScriptContext import BaseScriptContext
+from .RunningContextContainer import RunningContextContainer
 
 Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
@@ -18,7 +18,7 @@ class CancelScreen(BaseScreen):
 		pass
 
 	@overload
-	def addContainer(self, t: ScriptContext) -> None:
+	def addContainer(self, t: BaseScriptContext) -> None:
 		pass
 
 	@overload
