@@ -2,11 +2,9 @@ from typing import overload
 from typing import List
 from typing import TypeVar
 from typing import Mapping
-from .ScriptTrigger import *
+from .ScriptTrigger import ScriptTrigger
 
 JsonObject = TypeVar["com.google.gson.JsonObject"]
-List = TypeVar["java.util.List_java.lang.String_"]
-Map = TypeVar["java.util.Map_java.lang.String,java.lang.String_"]
 
 class CoreConfigV2:
 	maxLockTime: float
