@@ -1,7 +1,7 @@
 from typing import overload
 from typing import TypeVar
-from .IEventListener import *
-from .MethodWrapper import *
+from .IEventListener import IEventListener
+from .MethodWrapper import MethodWrapper
 
 Thread = TypeVar["java.lang.Thread"]
 
