@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .AbstractSettingField import *
-from .AbstractSettingContainer import *
-from .SettingsOverlay_SettingField import *
+from .AbstractSettingField import AbstractSettingField
+from .AbstractSettingContainer import AbstractSettingContainer
+from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 File = TypeVar["java.io.File"]
