@@ -1,9 +1,9 @@
 from typing import overload
 from typing import TypeVar
-from .OverlayContainer import *
-from .IOverlayParent import *
+from .OverlayContainer import OverlayContainer
+from .IOverlayParent import IOverlayParent
 
-T = TypeVar["T"]
+T = TypeVar("T")
 Element = TypeVar["net.minecraft.client.gui.Element"]
 
 class IContainerParent:
