@@ -1,12 +1,13 @@
 from typing import overload
 from typing import TypeVar
-from .BaseHelper import *
-from .ItemStackHelper import *
-from .NBTElementHelper import *
+from .BaseHelper import BaseHelper
+from .NBTElementHelper import NBTElementHelper
 
 ItemStack = TypeVar["net.minecraft.item.ItemStack"]
 
 class ItemStackHelper(BaseHelper):
+	"""
+	"""
 
 	@overload
 	def __init__(self, i: ItemStack) -> None:
@@ -14,54 +15,91 @@ class ItemStackHelper(BaseHelper):
 
 	@overload
 	def setDamage(self, damage: int) -> "ItemStackHelper":
+		"""Sets the item damage value.
+
+You may want to use ItemStackHelper#copy() first.\n
+		Since: 1.2.0 
+
+		Args:
+			damage: 
+		"""
 		pass
 
 	@overload
 	def isDamageable(self) -> bool:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def isEnchantable(self) -> bool:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def getDamage(self) -> int:
+		"""
+		"""
 		pass
 
 	@overload
 	def getMaxDamage(self) -> int:
+		"""
+		"""
 		pass
 
 	@overload
 	def getDefaultName(self) -> str:
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	@overload
 	def getName(self) -> str:
+		"""
+		"""
 		pass
 
 	@overload
 	def getCount(self) -> int:
+		"""
+		"""
 		pass
 
 	@overload
 	def getMaxCount(self) -> int:
+		"""
+		"""
 		pass
 
 	@overload
 	def getNBT(self) -> NBTElementHelper:
+		"""
+		Since: 1.1.6, was a String until 1.5.1 
+		"""
 		pass
 
 	@overload
 	def getCreativeTab(self) -> str:
+		"""
+		Since: 1.1.3 
+		"""
 		pass
 
 	@overload
 	def getItemID(self) -> str:
+		"""
+		"""
 		pass
 
 	@overload
 	def isEmpty(self) -> bool:
+		"""
+		"""
 		pass
 
 	@overload
@@ -70,38 +108,89 @@ class ItemStackHelper(BaseHelper):
 
 	@overload
 	def equals(self, ish: "ItemStackHelper") -> bool:
+		"""
+		Since: 1.1.3 [citation needed] 
+
+		Args:
+			ish: 
+		"""
 		pass
 
 	@overload
-	def equals(self, is: ItemStack) -> bool:
+	def equals(self, is_: ItemStack) -> bool:
+		"""
+		Since: 1.1.3 [citation needed] 
+
+		Args:
+			is: 
+		"""
 		pass
 
 	@overload
 	def isItemEqual(self, ish: "ItemStackHelper") -> bool:
+		"""
+		Since: 1.1.3 [citation needed] 
+
+		Args:
+			ish: 
+		"""
 		pass
 
 	@overload
-	def isItemEqual(self, is: ItemStack) -> bool:
+	def isItemEqual(self, is_: ItemStack) -> bool:
+		"""
+		Since: 1.1.3 [citation needed] 
+
+		Args:
+			is: 
+		"""
 		pass
 
 	@overload
 	def isItemEqualIgnoreDamage(self, ish: "ItemStackHelper") -> bool:
+		"""
+		Since: 1.1.3 [citation needed] 
+
+		Args:
+			ish: 
+		"""
 		pass
 
 	@overload
-	def isItemEqualIgnoreDamage(self, is: ItemStack) -> bool:
+	def isItemEqualIgnoreDamage(self, is_: ItemStack) -> bool:
+		"""
+		Since: 1.1.3 [citation needed] 
+
+		Args:
+			is: 
+		"""
 		pass
 
 	@overload
 	def isNBTEqual(self, ish: "ItemStackHelper") -> bool:
+		"""
+		Since: 1.1.3 [citation needed] 
+
+		Args:
+			ish: 
+		"""
 		pass
 
 	@overload
-	def isNBTEqual(self, is: ItemStack) -> bool:
+	def isNBTEqual(self, is_: ItemStack) -> bool:
+		"""
+		Since: 1.1.3 [citation needed] 
+
+		Args:
+			is: 
+		"""
 		pass
 
 	@overload
 	def copy(self) -> "ItemStackHelper":
+		"""
+		Since: 1.2.0 
+		"""
 		pass
 
 	pass
