@@ -1,11 +1,10 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .LivingEntityHelper import *
-from .TradeOfferHelper import *
+from .LivingEntityHelper import LivingEntityHelper
+from .TradeOfferHelper import TradeOfferHelper
 
 MerchantEntity = TypeVar["net.minecraft.entity.passive.MerchantEntity"]
-List = TypeVar["java.util.List_xyz.wagyourtail.jsmacros.client.api.helpers.TradeOfferHelper_"]
 
 class MerchantEntityHelper(LivingEntityHelper):
 
@@ -15,14 +14,20 @@ class MerchantEntityHelper(LivingEntityHelper):
 
 	@overload
 	def getTrades(self) -> List[TradeOfferHelper]:
+		"""
+		"""
 		pass
 
 	@overload
 	def getExperience(self) -> int:
+		"""
+		"""
 		pass
 
 	@overload
 	def hasCustomer(self) -> bool:
+		"""
+		"""
 		pass
 
 	pass
