@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .IHorseScreen import *
+from .IHorseScreen import IHorseScreen
 
 Entity = TypeVar["net.minecraft.entity.Entity"]
 
