@@ -1,10 +1,12 @@
 from typing import overload
-from .PositionCommon_Pos2D import *
-from .PositionCommon_Vec2D import *
-from .PositionCommon_Vec3D import *
+from .PositionCommon_Pos2D import PositionCommon_Pos2D
+from .PositionCommon_Vec3D import PositionCommon_Vec3D
 
 
 class PositionCommon_Vec2D:
+	"""
+	Since: 1.2.6 [citation needed] 
+	"""
 	x1: float
 	y1: float
 	x2: float
