@@ -1,10 +1,12 @@
 from typing import overload
-from .PositionCommon_Vec2D import *
-from .PositionCommon_Pos3D import *
-from .PositionCommon_Vec3D import *
+from .PositionCommon_Vec2D import PositionCommon_Vec2D
+from .PositionCommon_Pos3D import PositionCommon_Pos3D
 
 
 class PositionCommon_Vec3D(PositionCommon_Vec2D):
+	"""
+	Since: 1.2.6 [citation needed] 
+	"""
 	z1: float
 	z2: float
 
