@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .BaseProfile import *
-from .Core import *
-from .BaseEvent import *
+from .BaseProfile import BaseProfile
+from .Core import Core
+from .BaseEvent import BaseEvent
 
 Throwable = TypeVar["java.lang.Throwable"]
 
@@ -24,6 +24,10 @@ class Profile(BaseProfile):
 	def logError(self, ex: Throwable) -> None:
 		pass
 
+	@overload
+	def checkJoinedThreadStack(self) -> bool:
+		pass
+
 	@overload
 	def initRegistries(self) -> None:
 		pass
