@@ -2,13 +2,15 @@ from typing import overload
 from typing import List
 from typing import TypeVar
 from typing import Mapping
-from .AbstractRenderCodeCompiler import *
-from .EditorScreen import *
-from .AutoCompleteSuggestion import *
+from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler
+from .EditorScreen import EditorScreen
+from .AutoCompleteSuggestion import AutoCompleteSuggestion
 
 Runnable = TypeVar["java.lang.Runnable"]
 
 class ScriptCodeCompiler(AbstractRenderCodeCompiler):
+	"""
+	"""
 
 	@overload
 	def __init__(self, language: str, screen: EditorScreen, scriptFile: str) -> None:
